#
# spec file for package realmd
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           realmd
Version:        0.16.3
Release:        lp152.4.6.1
Summary:        AD integration detection
License:        LGPL-2.1+
Group:          System/GUI/GNOME
Url:            http://www.freedesktop.org/software/realmd
Source:         http://www.freedesktop.org/software/realmd/releases/%{name}-%{version}.tar.gz
Patch1:         0001-Fix-pam-misconfiguration-for-SUSE-systems.patch
Patch2:         0002-Fix-nsswitch-handling-when-joining-and-leaving-domai.patch

BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gettext-tools
BuildRequires:  glib2-devel >= 2.36
BuildRequires:  intltool
BuildRequires:  krb5-devel
BuildRequires:  libpackagekit-glib2-devel
BuildRequires:  libtool
BuildRequires:  openldap2-devel
BuildRequires:  polkit-devel
BuildRequires:  systemd
BuildRequires:  xmlto
Recommends:     %{name}-lang
%{?systemd_requires}

%description
This packages contains realmd.

Realmd is an on demand system DBus service, which allows
callers to configure network authentication and domain
membership in a standard way. realmd discovers information
about the domain or realm automatically and does not require
complicated configuration in order to join a domain or realm.

realmd configures sssd or winbind to do the actual network
authentication and user account lookups.

%lang_package

%prep
%setup -q
%autopatch -p1

%build
# krb5-config is hidden
PATH=$PATH:%{_prefix}/lib/mit/bin
%configure --with-distro=suse --with-systemd-unit-dir=%{_prefix}/lib/systemd/system --with-systemd-journal=no
make %{?_smp_mflags}

%install
%make_install

%find_lang %{name}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}

%pre
if [ -f %{_localstatedir}/lib/systemd/migrated/%{name} ]; then
%service_add_pre %{name}.service
fi

%post
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%defattr(-,root,root)
%{_sbindir}/realm
%{_sbindir}/rc%{name}
%{_unitdir}/realmd.service
%{_prefix}/lib/realmd/
%config %{_sysconfdir}/dbus-1/system.d/org.freedesktop.realmd.conf
%{_datadir}/dbus-1/system-services/org.freedesktop.realmd.service
%{_datadir}/polkit-1/actions/org.freedesktop.realmd.policy

%{_datadir}/doc/realmd
%{_mandir}/man5/realmd.conf.5%{ext_man}
%{_mandir}/man8/realm.8%{ext_man}

%files lang -f %{name}.lang

%changelog
* Wed Dec  2 2020 Samuel Cabrero <scabrero@suse.de>
- Fix nsswitch handling when joining and leaving a domain; (bsc#1175617);
  Add 0002-Fix-nsswitch-handling-when-joining-and-leaving-domai.patch
* Wed Aug 26 2020 Samuel Cabrero <scabrero@suse.de>
- Fix pam misconfiguration; (bsc#1175616); Add
  0001-Fix-pam-misconfiguration-for-SUSE-systems.patch
* Wed Jul 19 2017 plinnell@opensuse.org
- https://bugzilla.suse.com/show_bug.cgi?id=916766
  and https://bugzilla.suse.com/show_bug.cgi?id=1048025 resolved.
* Fri Dec 16 2016 plinnell@suse.com
- update to 0.16.3
- some minor package tweaks
- Add rpmlint filter for polkit error - A temp fix until security
  review is completed.
* Fri May 20 2016 darin@darins.net
- update to 0.16.2
  * Be more liberal with domain name chars
  * Increase timeout when calling PackageKit
  * List package names with spaces between them [#89464]
  * Install to $prefix/lib instead of $libdir
  + 0.16.1
  * libsystemd build fix [#90519]
  * Change default home directory to /home/%%U@%%D
  * Add --automatic-id-mapping=no command line argument
  + 0.16.0
  * Disable automatic AD joins by default [#89205]
  * Validate text we receive from LDAP
  * Prefer adcli for AD joins
  * Remove hard dependency on PackageKit
  * Fix crash when empty password is used with realm client
* Wed Apr 22 2015 kkaempf@suse.com
- update to 0.16.0
  * Disable automatic AD joins unless explicitly configured to
    do so. This guarantees that mutual trust is established with
    a domain that you are joining.
  * Validate textual data discovered via LDAP before using them
    in configuration files like samba.conf and sssd.conf
* Sun Feb  8 2015 kkaempf@suse.com
- update to 0.15.2
  * Bugfix release
  * systemd support
  * automake 1.14 support
* Tue Mar 25 2014 kkaempf@suse.com
- Upgrade to 0.14.5
  Bugfix release
* Thu May 16 2013 jmcdonough@suse.com
- Add docs and cleanup some build warnings
* Wed May 15 2013 jmcdonough@suse.com
- Check in 0.14.1
